#!/bin/bash

#------------------------------------------------------------------------------
# sends program output
# -----------------------------------------------------------------------------

# usage

usage() {
  echo "usage: $0 -a ep_appl@localhost [ -s 'Output from SybaseBackup.sh' ] -f SybaseBackup.log"
  echo "OPTIONS:"
  echo "   -a: addressee (e-mail address) (mandatory)"
  echo "   -s: e-mail subject (optional)"
  echo "   -f: name of file to sent (mandatory)"
  exit 1
}

unset RECIPIENT SUBJECT FILE
while getopts a:s:f: c ; do
  case $c in
    a)	RECIPIENT=$OPTARG ;;
    s)	SUBJECT=$OPTARG ;;
    f)	FILE=$OPTARG ;;
    *) usage ;;
  esac
done

[ "x" = "x$RECIPIENT" -o "x" = "x$FILE" ] && usage
[ "x" = "x$SUBJECT" ] && SUBJECT="Notification from ePages"

if [ ! -f $FILE ] ; then
    echo "File not sent: no such file ($FILE)."
    exit
elif [ ! -s $FILE ] ; then
    echo "File not sent: file empty ($FILE)."
    exit
fi

# set environment

EPAGES_PROJECT=${EPAGES_PROJECT:-epages6}
EPAGES_DEFAULT=/etc/default/$EPAGES_PROJECT
[ -x $EPAGES_DEFAULT ] && . $EPAGES_DEFAULT

# main program

EP_MAIL=$(type -p mailx)
EP_MAIL=${EP_MAIL:-$(type -p mail)}

[ -z "$EP_MAIL" ] && { which mail; exit 1; }

cat $FILE | eval $EP_MAIL $SUBJECT $RECIPIENT

# end
